@@ -1,10 +1,7 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-
 """4 axis stepper motor driver with and Ethernet interface."""
 
 
-from .stepXXX import STEPXXX
+from stepseries.stepXXX import STEPXXX
 
 
 class STEP400(STEPXXX):
